@@ -242,10 +242,7 @@ class IO(threading.Thread, base.StatefulObject):
             self._exceptions.put(exceptions.ConnectionException(*args))
         self._set_state(self.CLOSED)
         self._loop.stop()
-        try:
-            self._write_trigger.send('0')
-        except socket.error:
-            pass
+        self._trigger_write()
         self._events.clear(events.SOCKET_OPENED)
         self._events.set(events.SOCKET_CLOSED)
         self._events.set(events.EXCEPTION_RAISED)
@@ -504,3 +501,13 @@ class IO(threading.Thread, base.StatefulObject):
         server.setblocking(0)
         client.setblocking(0)
         return server, client
+
+    def _trigger_write(self):
+        """Notifies the IO loop we need to write a frame by writing a byte
+        to a local socket.
+
+        """
+        try:
+            self._write_trigger.send(b'0')
+        except socket.error:
+            pass
